pyriskadjust.coefficients package
=================================

Submodules
----------

pyriskadjust.coefficients.coefficients\_2018\_v21 module
--------------------------------------------------------

.. automodule:: pyriskadjust.coefficients.coefficients_2018_v21
    :members:
    :undoc-members:
    :show-inheritance:

pyriskadjust.coefficients.coefficients\_2018\_v22 module
--------------------------------------------------------

.. automodule:: pyriskadjust.coefficients.coefficients_2018_v22
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: pyriskadjust.coefficients
    :members:
    :undoc-members:
    :show-inheritance:
